@@ -19,10 +19,10 @@
 
 #authors: Peter Parente, Mark Doffman
 
-import Accessibility
-from deviceevent import allModifiers
-import state
-import registry
+import pyatspi.Accessibility
+from pyatspi.deviceevent import allModifiers
+import pyatspi.state as state
+import pyatspi.registry as registry
 
 #from deviceevent import *
 
@@ -155,7 +155,7 @@ def relationToString(value):
         @return: Human readable, untranslated name of the relation
         @rtype: string
         """
-        return Accessibility.RELATION_VALUE_TO_NAME.get(value)
+        return pyatspi.Accessibility.RELATION_VALUE_TO_NAME.get(value)
 
 
 def findDescendant(acc, pred, breadth_first=False):
